PreprocessError

Enum PreprocessError 

pub enum PreprocessError {
    IncludeNotFound(ResolveError),
    IncludeCycle {
        file: String,
    },
    UnmatchedEndif {
        file: String,
        line: usize,
    },
    UnmatchedElse {
        file: String,
        line: usize,
    },
    UnclosedConditional {
        file: String,
        line: usize,
    },
    SyntaxError {
        file: String,
        line: usize,
        message: String,
    },
    ErrorDirective {
        file: String,
        line: usize,
        message: String,
    },
    TrailingBackslash {
        file: String,
    },
}
Top-level preprocessor error.

Variants



IncludeNotFound(ResolveError)

#include could not be resolved.



IncludeCycle

#include already in the expansion stack — cycle detected.

Fields

file: String

File that was to be included cyclically.



UnmatchedEndif

#endif without a matching #ifdef/#ifndef.

Fields

file: String

Source file of the unmatched directive.

line: usize

1-indexed line.



UnmatchedElse

#else without a matching #ifdef/#ifndef.

Fields

file: String
line: usize


UnclosedConditional

#ifdef/#ifndef without a closing #endif.

Fields

file: String
line: usize


SyntaxError

Directive with faulty syntax (e.g. #define without a name).

Fields

file: String
line: usize
message: String


ErrorDirective

#error <message> — explicitly requested build stop.

Fields

file: String

Source file.

line: usize

Line.

message: String

Content of the directive.



TrailingBackslash

Backslash as the last character in the source file — Spec 7.3: “A backslash character may not be the last character in a source file.”

Fields

file: String

Source file.